@@ -725,6 +725,19 @@ class GroCropClient(object):
             }
         return self.get_data_points(**params)
 
+    def get_dtn_fertilizer_prices(self, fertilizer_id: int, region_id: int, start_date: str = None, end_date: str = None):
+        """Returns facility-level basis prices for a fertilizer and a region at state (L4) and national (L3) levels."""
+        params = {
+            "source_id": SourceList.DTN,
+            "frequency_id": 2,
+            "item_id":  fertilizer_id,
+            "region_id": region_id,
+            "metric_id": MetricList.RETAIL_PRICES_CLOSE_INDEX,
+            "start_date": start_date,
+            "end_date": end_date
+            }
+        return self.get_data_points(**params)
+
     def get_dtn_facilities(self, region_id: int, crop: int, include_lat_longs: bool = False):
         """Returns DTN facility IDs for a specific region, optionally adding the lat/longs for each facility"""
         params = {
